@@ -25,8 +25,8 @@ class ConfigParameter(param.Parameter):
         super()._set_names(attrib_name)
         
 class Config(param.Parameterized):
-    API_SERVER = ConfigParameter(str, env_prefix="xepmts", default="https://xestore-dot-xenon-pmts.uc.r.appspot.com/v1")
-    AUTH_SERVER_URI = ConfigParameter(str, env_prefix="xepmts", default="https://pmts.xenonnt.org/db_api/jwt/device/")
+    API_SERVER = ConfigParameter(str, env_prefix="xepmts", default="https://xe1t-mysql.lngs.infn.it/api/v1")
+    AUTH_SERVER_URI = ConfigParameter(str, env_prefix="xepmts", default="https://xe1t-mysql.lngs.infn.it/xeauth/")
     API_TOKEN = ConfigParameter(str, env_prefix="xepmts", default="")
     DEBUG = ConfigParameter(bool, env_prefix="xepmts", default=False)
     MAX_LOG_SIZE = 20
